@@ -1,10 +1,19 @@
+import logging
+
+import json
+
+from rest_framework import status
 from rest_framework.response import Response
 from rest_framework.generics import GenericAPIView
 from rest_framework.renderers import JSONRenderer
+from rest_framework.exceptions import ParseError
 
 from django.views.decorators.csrf import csrf_exempt
-import json
-from .models import Hook
+from .models import Hook, hook_signal
+
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.DEBUG)
+logging.basicConfig()
 
 
 class HookView(GenericAPIView):
@@ -16,7 +25,12 @@ class HookView(GenericAPIView):
         name = kwargs.get('name', None)
 
         # Git repo information from post-receive payload
-        payload = json.loads(request.DATA.get('payload', "{}"))
+        if request.content_type == "application/json":
+            payload = request.data
+        else:
+            # Probably application/x-www-form-urlencoded
+            payload = json.loads(request.data.get("payload", "{}"))
+
         info = payload.get('repository', {})
         repo = info.get('name', None)
 
@@ -27,7 +41,7 @@ class HookView(GenericAPIView):
             user = user.get('name', None)
 
         if not name and not repo and not user:
-            raise Exception(
+            raise ParseError(
                 "No JSON data or URL argument : cannot identify hook"
             )
 
@@ -40,7 +54,13 @@ class HookView(GenericAPIView):
             elif repo and user:
                 hook = Hook.objects.get(user=user, repo=repo)
             if hook:
-                hook.execute()
+                if hook.path != "send-signal":
+                    hook.execute()
+                else:
+                    hook_signal.send(HookView, info=info, repo=repo, user=user, request=request)
+                    
         except Hook.DoesNotExist:
-            pass
+            # If there is not a script defined, then send a HookSignal
+            hook_signal.send(HookView, request=request, payload=payload)
+            logger.debug('Signal {} sent'.format(hook_signal))
         return Response({})
